Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountInfoRequest ¶
type AccountInfoResponse ¶
type AccountInfoResponse struct {
Result struct {
AccountData struct {
Account string `json:"Account"`
Balance string `json:"Balance"`
Flags int `json:"Flags"`
LedgerEntryType string `json:"LedgerEntryType"`
OwnerCount int `json:"OwnerCount"`
PreviousTxnID string `json:"PreviousTxnID"`
PreviousTxnLgrSeq int `json:"PreviousTxnLgrSeq"`
RegularKey string `json:"RegularKey"`
Sequence int `json:"Sequence"`
Index string `json:"index"`
} `json:"account_data"`
LedgerCurrentIndex int `json:"ledger_current_index"`
QueueData struct {
TxnCount int `json:"txn_count"`
} `json:"queue_data"`
Status string `json:"status"`
Validated bool `json:"validated"`
} `json:"result"`
}
type Request ¶
type Request struct {
Method string `json:"method"`
Params []interface{} `json:"params"`
}
type SubmitRequest ¶
type SubmitRequest struct {
TxBlob string `json:"tx_blob"`
}
type SubmitResponse ¶
type SubmitResponse struct {
}
type XRP ¶
type XRP interface {
Do(dst interface{}, method string, params ...interface{}) error
AccountInfo(request AccountInfoRequest) (*AccountInfoResponse, error)
Submit(request SubmitRequest) (*SubmitResponse, error)
Sign(transaction data.Transaction, fee data.Value) error
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package config provides a simple way of signing submitting groups of transactions for the same account.
|
Package config provides a simple way of signing submitting groups of transactions for the same account. |
|
Package data aims to provides all the data types that are needed to build tools, clients and servers for use on the Ripple network.
|
Package data aims to provides all the data types that are needed to build tools, clients and servers for use on the Ripple network. |
|
Utiltities for formatting Ripple data in a terminal
|
Utiltities for formatting Ripple data in a terminal |
|
tools
|
|
|
book
command
|
|
|
explain
command
Tool to explain transactions either individually, in a ledger or belonging to an account.
|
Tool to explain transactions either individually, in a ledger or belonging to an account. |
|
lines
command
|
|
|
offers
command
|
|
|
submit
command
|
|
|
subscribe
command
|
|
|
trades
command
|
|
|
vanity
command
Simple tool to find the seeds for ripple account ids which match a regular expression
|
Simple tool to find the seeds for ripple account ids which match a regular expression |
Click to show internal directories.
Click to hide internal directories.